/**
 * EasyBeans
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IENCBindingHolder.java 5558 2010-07-05 14:58:03Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api.enc;

import java.util.List;
import java.util.Map;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;

/**
 * Manage different types that need to be stored in ENC env.
 * @author Florent BENOIT
 */
public interface IENCBindingHolder {

    /**
     * @return the list of persistence context bindings.
     */
    List<IENCBinding<IJavaxPersistenceContext>> getPersistenceContextBindings();

    /**
     * @return the list of persistence unit bindings.
     */
    List<IENCBinding<IJavaxPersistenceUnit>> getPersistenceUnitBindings();

    /**
     * @return the list of resource bindings.
     */
    List<IENCBinding<IJAnnotationResource>> getResourceBindings();

    /**
     * @return the list of EJB bindings.
     */
    List<IENCBinding<IJEjbEJB>> getEJBBindings();

    /**
     * @return the list of WS bindings.
     */
    List<IENCBinding<IJaxwsWebServiceRef>> getWebServicesBindings();

    /**
     * @param className the name of the class for which the fields are requested
     * @return the injection target enc objects for a given classname
     */
    List<IInjectionTargetEnc> getFieldInjectionTargets(final String className);

    /**
     * @param className the name of the class for which the methods are requested
     * @return the injection target enc objects for a given classname
     */
    List<IInjectionTargetEnc> getMethodInjectionTargets(final String className);

    /**
     * List of fields/method that needs to be set for a given class.
     * @return a map with key = classname and then map = field/attribute name <--> value
     */
    Map<String, Map<String, String>> getInjectionMap();
}
