/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IEnvironmentRefAccessor.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api.interfaces;

import java.util.Collection;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.struct.IEnvEntry;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;

/**
 * This interface provides method to keep env state.
 * @author Gael Lalire
 */
public interface IEnvironmentRefAccessor extends ISharedMetadata {

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs}
     *         annotation.
     */
    List<IJEjbEJB> getJEjbEJBs();

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs);

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    List<IJAnnotationResource> getJAnnotationResources();

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources);

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts();

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    void setJavaxPersistencePersistenceContexts(final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts);

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits();

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits);

    /**
     * @return jaxwsWebServiceRefs list representing &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs();

    /**
     * Sets setJaxwsWebServiceRefs object.
     * @param jaxwsWebServiceRefs list representing &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    void setJaxwsWebServiceRefs(final List<IJaxwsWebServiceRef> jaxwsWebServiceRefs);

    /**
     * @return a collection of env-entry
     */
    Collection<? extends IEnvEntry> getEnvEntryCollection();

    /**
     * @param envEntryCollection a collection of env-entry
     */
    void setEnvEntryCollection(Collection<? extends IEnvEntry> envEntryCollection);

    /**
     * @return the environment name.
     */
    String getEnvironmentName();

}
